
import * as React from 'react';

interface IconProps extends React.SVGAttributes<SVGElement> {
  children?: never;
  color?: string;
}

/**
 * @name DocumentPlusIcon
 * @alias AddIcon
 *
 * @category solid
 *
 * @description
 * El ícono DocumentPlus representa la acción de agregar un nuevo documento. Visualmente, muestra un documento con un símbolo de más (+).
 *
 * 
 * @usage
 * - Botones para permitir a los usuarios agregar nuevos registros.
 * - Enlaces para destacar la opción de agregar contenido.
 * - Formularios donde se necesite la acción de crear nuevos registros.
 *
 * @accessibility
 * Asegurarse de incluir un atributo `aria-label` o `aria-hidden="true"` si el ícono es decorativo.
 *
 * @returns {JSX.Element} Componente SVG.
 */
const DocumentPlusIcon = React.forwardRef<SVGSVGElement, IconProps>(
  ({ color = 'currentColor', ...props }, forwardedRef) => {
    return (
      <svg {...props} ref={forwardedRef} xmlns="http://www.w3.org/2000/svg" fill="none" stroke-width="1.5" aria-hidden="true" data-slot="icon" viewBox="0 0 24 24" stroke="currentColor"><path stroke-linecap="round" stroke-linejoin="round" d="M19.5 14.25v-2.625a3.375 3.375 0 0 0-3.375-3.375h-1.5A1.125 1.125 0 0 1 13.5 7.125v-1.5a3.375 3.375 0 0 0-3.375-3.375H8.25m3.75 9v6m3-3H9m1.5-12H5.625c-.621 0-1.125.504-1.125 1.125v17.25c0 .621.504 1.125 1.125 1.125h12.75c.621 0 1.125-.504 1.125-1.125V11.25a9 9 0 0 0-9-9Z"/></svg>
    );
  }
);

DocumentPlusIcon.displayName = 'DocumentPlusIcon';

export { DocumentPlusIcon, DocumentPlusIcon as AddIcon };
